Struct DevicePathUtilitiesProtocol
Source #[repr(C)]
pub struct DevicePathUtilitiesProtocol {
pub get_device_path_size: unsafe extern "efiapi" fn(device_path: *const DevicePathProtocol) -> usize,
pub duplicate_device_path: unsafe extern "efiapi" fn(device_path: *const DevicePathProtocol) -> *const DevicePathProtocol,
pub append_device_path: unsafe extern "efiapi" fn(src1: *const DevicePathProtocol, src2: *const DevicePathProtocol) -> *const DevicePathProtocol,
pub append_device_node: unsafe extern "efiapi" fn(device_path: *const DevicePathProtocol, device_node: *const DevicePathProtocol) -> *const DevicePathProtocol,
pub append_device_path_instance: unsafe extern "efiapi" fn(device_path: *const DevicePathProtocol, device_path_instance: *const DevicePathProtocol) -> *const DevicePathProtocol,
pub get_next_device_path_instance: unsafe extern "efiapi" fn(device_path_instance: *mut *const DevicePathProtocol, device_path_instance_size: *mut usize) -> *const DevicePathProtocol,
pub is_device_path_multi_instance: unsafe extern "efiapi" fn(device_path: *const DevicePathProtocol) -> bool,
pub create_device_node: unsafe extern "efiapi" fn(node_type: DeviceType, node_sub_type: DeviceSubType, node_length: u16) -> *const DevicePathProtocol,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.